@@ -4,10 +4,11 @@ use base qw(File::Find::Rule);
 use strict;
 use warnings;
 
+use List::MoreUtils qw(any);
 use Parse::DMIDecode;
 use Perl6::Slurp;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Detect dmidecode file.
 sub File::Find::Rule::dmidecode_file {
@@ -24,6 +25,20 @@ sub File::Find::Rule::dmidecode_file {
 	});
 }
 
+sub File::Find::Rule::dmidecode_handle {
+	my ($file_find_rule, $handle) = @_;
+	my $self = $file_find_rule->_force_object;
+	return $self->file->exec(sub{
+		my $file = shift;
+
+		my $data = slurp($file);
+		my $dmidecode = Parse::DMIDecode->new;
+		$dmidecode->parse($data);
+
+		return any { $_->handle eq $handle } $dmidecode->get_handles;
+	});
+}
+
 1;
 
 __END__
@@ -42,6 +57,7 @@ File::Find::Rule::DMIDecode - Common rules for searching for dmidecode files.
  use File::Find::Rule::DMIDecode;
 
  my @files = File::Find::Rule->dmidecode_file->in($dir);
+ my @files = File::Find::Rule->dmidecode_handle($handle)->in($dir);
 
 =head1 DESCRIPTION
 
@@ -63,7 +79,13 @@ See L<DMI on Wikipedia|https://en.wikipedia.org/wiki/Desktop_Management_Interfac
 
 The C<dmidecode_file()> rule detect dmidecode files by parsing of structure.
 
-=head1 EXAMPLE
+=head2 C<dmidecode_handle>
+
+ my @files = File::Find::Rule->dmidecode_handle($handle)->in($dir);
+
+The C<dmidecode_handle($handle)> rule detect dmidecode handle in file.
+
+=head1 EXAMPLE1
 
  use strict;
  use warnings;
@@ -86,9 +108,34 @@ The C<dmidecode_file()> rule detect dmidecode files by parsing of structure.
  # Output like:
  # Usage: qr{[\w\/]+} dir
 
+=head1 EXAMPLE2
+
+ use strict;
+ use warnings;
+
+ use File::Find::Rule;
+ use File::Find::Rule::DMIDecode;
+
+ # Arguments.
+ if (@ARGV < 2) {
+         print STDERR "Usage: $0 dir handle\n";
+         exit 1;
+ }
+ my $dir = $ARGV[0];
+ my $handle = $ARGV[1];
+
+ # Print all dmidecode handles in directory.
+ foreach my $file (File::Find::Rule->dmidecode_handle($handle)->in($dir)) {
+         print "$file\n";
+ }
+
+ # Output like:
+ # Usage: qr{[\w\/]+} dir
+
 =head1 DEPENDENCIES
 
 L<File::Find::Rule>,
+L<List::MoreUtils>,
 L<Parse::DMIDecode>,
 L<Perl6::Slurp>.
 
@@ -120,6 +167,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
